==> zio-aws-secretsmanager_2.13-5.17.158.1-sources.jar: zio/aws/secretsmanager/model/FilterNameStringType.scala <==
package zio.aws.secretsmanager.model
import scala.jdk.CollectionConverters._
sealed trait FilterNameStringType {
  def unwrap: software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType
}
object FilterNameStringType {
  def wrap(
      value: software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType
  ): zio.aws.secretsmanager.model.FilterNameStringType = value match {
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.DESCRIPTION =>
      val r = description
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.NAME =>
      val r = name
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.TAG_KEY =>
      val r = `tag-key`
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.TAG_VALUE =>
      val r = `tag-value`
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.PRIMARY_REGION =>
      val r = `primary-region`
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.ALL =>
      val r = all
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.UNKNOWN_TO_SDK_VERSION
  }
  case object description
      extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.DESCRIPTION
  }
  case object name extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.NAME
  }
  case object `tag-key`
      extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.TAG_KEY
  }
  case object `tag-value`
      extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.TAG_VALUE
  }
  case object `primary-region`
      extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.PRIMARY_REGION
  }
  case object all extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.ALL
  }
}

==> zio-aws-secretsmanager_2.13-5.20.22.1-sources.jar: zio/aws/secretsmanager/model/FilterNameStringType.scala <==
package zio.aws.secretsmanager.model
import scala.jdk.CollectionConverters._
sealed trait FilterNameStringType {
  def unwrap: software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType
}
object FilterNameStringType {
  def wrap(
      value: software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType
  ): zio.aws.secretsmanager.model.FilterNameStringType = value match {
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.DESCRIPTION =>
      val r = description
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.NAME =>
      val r = name
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.TAG_KEY =>
      val r = `tag-key`
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.TAG_VALUE =>
      val r = `tag-value`
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.PRIMARY_REGION =>
      val r = `primary-region`
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.OWNING_SERVICE =>
      val r = `owning-service`
      r
    case software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.ALL =>
      val r = all
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.UNKNOWN_TO_SDK_VERSION
  }
  case object description
      extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.DESCRIPTION
  }
  case object name extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.NAME
  }
  case object `tag-key`
      extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.TAG_KEY
  }
  case object `tag-value`
      extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.TAG_VALUE
  }
  case object `primary-region`
      extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.PRIMARY_REGION
  }
  case object `owning-service`
      extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.OWNING_SERVICE
  }
  case object all extends zio.aws.secretsmanager.model.FilterNameStringType {
    override def unwrap
        : software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType =
      software.amazon.awssdk.services.secretsmanager.model.FilterNameStringType.ALL
  }
}
